@@ -658,7 +658,7 @@ Evaluate the query operation for a given object.
 
 :Parameters:
 
-    x :
+    x : object
         See `evaluate`.
 
     parent_attr : tuple
